@@ -33,9 +33,10 @@
 #  define AKONADI_SEARCH_DEBUG_DEPRECATED_NO_EXPORT AKONADI_SEARCH_DEBUG_NO_EXPORT AKONADI_SEARCH_DEBUG_DEPRECATED
 #endif
 
-#define DEFINE_NO_DEPRECATED 0
-#if DEFINE_NO_DEPRECATED
-# define AKONADI_SEARCH_DEBUG_NO_DEPRECATED
+#if 0 /* DEFINE_NO_DEPRECATED */
+#  ifndef AKONADI_SEARCH_DEBUG_NO_DEPRECATED
+#    define AKONADI_SEARCH_DEBUG_NO_DEPRECATED
+#  endif
 #endif
 
 #endif
